Crate cpp_linter

Crate cpp_linter 

cpp-linter

This crate contains the the library used as a backend for the cpp-linter binary executable. The main focus of cpp-linter is as follows:

  • Lint C/C++ sources using clang-format and clang-tidy.
  • Respect file changes when run in a CI workflow on Github.
  • Provide feedback via Github’s REST API in the any of the following forms:
    • step summary
    • thread comments
    • file annotation
    • pull request review suggestions

See also the CLI document hosted on github.

Modules

clang_tools
This module holds the functionality related to running clang-format and/or clang-tidy.
cli
This module holds the Command Line Interface design.
common_fs
A module to hold all common file system functionality.
error
git
This module was primarily used to parse diff blobs.
rest_client