Module clang_tools

Module clang_tools 

This module holds the functionality related to running clang-format and/or clang-tidy.

Modules

clang_format
This module holds functionality specific to running clang-format and parsing it’s output.
clang_tidy
This module holds functionality specific to running clang-tidy and parsing it’s output.

Structs

ClangVersions
A struct to contain the version numbers of the clang-tools used
ReviewComments
A struct to describe the Pull Request review suggestions.
Suggestion
A struct to describe a single suggestion in a pull_request review.

Functions

capture_clang_tools_output
Runs clang-tidy and/or clang-format and returns the version used for each.
make_patch
A helper function to create a Diff and its associated InternedInput from a patched buffer and the `original_content`` of the file.