pub struct FeedbackOptions {
pub thread_comments: ThreadComments,
pub no_lgtm: bool,
pub step_summary: bool,
pub file_annotations: bool,
pub tidy_review: bool,
pub format_review: bool,
pub passive_reviews: bool,
}Expand description
A struct to describe the CLI’s feedback options.
Fields
thread_comments: ThreadCommentsSet this option to true to enable the use of thread comments as feedback.
[!NOTE] To use thread comments, the
GITHUB_TOKEN(provided by Github to each repository) must be declared as an environment variable.
no_lgtm: boolSet this option to true or false to enable or disable the use of a thread comment that basically says ‘Looks Good To Me’ (when all checks pass).
[!IMPORTANT] The
--thread-commentsoption also notes further implications.
step_summary: boolSet this option to true or false to enable or disable the use of a workflow step summary when the run has concluded.
file_annotations: boolSet this option to false to disable the use of file annotations as feedback.
tidy_review: boolSet to true to enable Pull Request reviews from clang-tidy.
format_review: boolSet to true to enable Pull Request reviews from clang-format.
passive_reviews: boolSet to true to prevent Pull Request reviews from
approving or requesting changes.