pub struct FormatOptions {
pub style: String,
pub ignore_format: Option<Vec<String>>,
}Expand description
A struct to describe the CLI’s clang-format options.
Fields
style: StringThe style rules to use.
- Set this to
fileto have clang-format use the closest relative .clang-format file. Same as passing no value to this option. - Set this to a blank string (
'') to disable using clang-format entirely.
[!NOTE] If this is not a blank string, then it is also passed to clang-tidy (if
--tidy_checksis not-*). This is done to ensure suggestions from both clang-tidy and clang-format are consistent.
ignore_format: Option<Vec<String>>Similar to --ignore but applied
exclusively to files analyzed by clang-format.