A module to hold all common file system functionality.
Structs
- A structure to represent a file’s path and line changes.
Functions
- Gets the line and column number from a given
offset(of bytes) for givenfile_path. - This was copied from cargo source code.