Module error

Module error 

This module defines error types for the cpp-linter crate.

Enums

ClangCaptureError
Errors related to invoking clang tools and processing their output.
ClangTaskError
Errors related to orchestrating clang tools in parallel.
ClientError
Errors related to the REST client used for posting feedback and special logging.
FileObjError
Errors related to FileObj methods’ results.