pub enum FileObjError {
ReadFile(Error),
FromUtf8Error(String, FromUtf8Error),
DisplayStringFailed(Error),
MkDirFailed(Error),
OpenPatchFileFailed(Error),
WritePatchFailed(Error),
}Expand description
Errors related to FileObj methods’ results.
Variants
ReadFile(Error)
Error when failing to read a file’s contents.
FromUtf8Error(String, FromUtf8Error)
Error when failing to convert a file’s contents to a UTF-8 string.
DisplayStringFailed(Error)
Error when failing to generate a patch for a file.
MkDirFailed(Error)
Error when failing to create the cache directory for the patch file.
OpenPatchFileFailed(Error)
Error when failing to open the patch file for writing.
WritePatchFailed(Error)
Error when failing to write to the patch file.