This module was primarily used to parse diff blobs.
Since migrating to git-bot-feedback crate, this module is now purely for regression testing. Any logic that parses diffs from 2 text blobs has been moved to git-bot-feedback. Some diff creation/parsing logic remains in clang_tools/mod.rs module using libgit2 API instead.