Module rest_client

Module rest_client 

This module defines the struct that wraps employs a REST API client.

Structs

RestClient
A wrapper struct around a REST API client.

Constants

COMMENT_MARKER
The comment marker used to identify bot comments from other comments (from users or other bots).
USER_AGENT
The UserAgent header value used in HTTP requests.
USER_OUTREACH
The user outreach message displayed in bot comments.