Module cpp_linter::run
source · Expand description
This module is the native backend of the cpp-linter package written in Rust.
In python, this module is exposed as cpp_linter.run that has 1 function exposed:
main().
Functions
- This is the backend entry point for console applications.