pub enum ClangCaptureError {
MutexPoisoned,
ToolPathUnknown(&'static str),
FailedToRunCommand {
task: String,
source: Error,
},
NonUtf8Output {
task: String,
source: FromUtf8Error,
},
ReadFileFailed {
file_name: String,
source: Error,
},
WriteFileFailed {
file_name: String,
source: Error,
},
RegexError(Error),
UnknownWorkingDirectory(Error),
ParseIntError(ParseIntError),
UnknownCacheParentPath,
MkDirFailed(Error),
}Expand description
Errors related to invoking clang tools and processing their output.
Variants
MutexPoisoned
Error when failing to acquire a lock on a file’s mutex.
ToolPathUnknown(&'static str)
Error when invoking a clang tool with no known path to the binary executable.
FailedToRunCommand
Error when a clang tool fails to be invoked.
Fields
NonUtf8Output
Error when the output of a clang tool cannot be parsed as a UTF-8 string.
Fields
source: FromUtf8ErrorThe underlying error from trying to convert the clang tool’s output to a UTF-8 string.
ReadFileFailed
Error when failing to read a file’s contents.
Fields
WriteFileFailed
Error when failing to write a file.
Fields
RegexError(Error)
Error when failing to compile a regular expression pattern.
UnknownWorkingDirectory(Error)
Error when failing to determine the current working directory.
ParseIntError(ParseIntError)
Error when failing to parse an integer from a string.
UnknownCacheParentPath
Error when failing to determine the parent directory for caching purposes.
MkDirFailed(Error)
Error when failing to create a directory for caching purposes.