This module defines the struct that wraps employs a REST API client.
Structs
- Rest
Client - A wrapper struct around a REST API client.
Constants
- COMMENT_
MARKER - The comment marker used to identify bot comments from other comments (from users or other bots).
- USER_
AGENT - The UserAgent header value used in HTTP requests.
- USER_
OUTREACH - The user outreach message displayed in bot comments.